summaryrefslogtreecommitdiff
path: root/nuttx/configs/twr-k60n512/src/up_buttons.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/twr-k60n512/src/up_buttons.c')
-rw-r--r--nuttx/configs/twr-k60n512/src/up_buttons.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/nuttx/configs/twr-k60n512/src/up_buttons.c b/nuttx/configs/twr-k60n512/src/up_buttons.c
index c836efee3..b81d0ea53 100644
--- a/nuttx/configs/twr-k60n512/src/up_buttons.c
+++ b/nuttx/configs/twr-k60n512/src/up_buttons.c
@@ -1,5 +1,5 @@
/****************************************************************************
- * configs/twr-k60n512/src/up_buttons.c
+ * configs/twr-k60n512/src/board_buttons.c
*
* Copyright (C) 2011, 2014 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
@@ -74,7 +74,7 @@
*
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
@@ -89,10 +89,10 @@ void board_button_initialize(void)
}
/****************************************************************************
- * Name: up_buttons
+ * Name: board_buttons
****************************************************************************/
-uint8_t up_buttons(void)
+uint8_t board_buttons(void)
{
uint8_t ret = 0;
@@ -114,12 +114,12 @@ uint8_t up_buttons(void)
*
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT
* definitions in board.h for the meaning of each bit.
*
@@ -74,7 +74,7 @@
* Description:
* board_button_initialize() must be called to initialize button resources. After
- * that, up_buttons() may be called to collect the current state of all
+ * that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
@@ -114,12 +114,12 @@ uint8_t up_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
- * that, up_buttons() may be called to collect the current state of all
+ * that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
@@ -114,12 +114,12 @@ uint8_t up_buttons(void)
* handlers.
*
- * After board_button_initialize() has been called, up_buttons() may be called to
- * collect the state of all buttons. up_buttons() returns an 8-bit bit set
+ * After board_button_initialize() has been called, board_buttons() may be called to
+ * collect the state of all buttons. board_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT
* definitions in board.h for the meaning of each bit.